# Sample Draft script:  Basic Quicktime
# Convert linear frames to 1080 pixel height H264 and adds an audio track
#
#
# When submitting this script to Deadline, the following Draft Options should be set:
#   Input File:  Select one of the frames in the sequence that will be processed.
#   Output File:  Leave it as Deadline auto-fills, or select an alternate location/name for the movie file.
#   Frame List:  Leave it as Deadline auto-fills, or specify a subset of the frames.
#
#
# If running this script from the command line, 
#   infile:  The pattern that the input files follow, for example frame_name_###.ext, where ### represents a three digit
#            frame number, due to there being three hash marks.
#   outfile:  The (path and) filename of the movie file.
#   frameList:  The list of frames to be processed.
#
# In regards to audio,
#   This script will take the first audio file (wav, aiff or aif) from infile's parent directory and
#   applies it to the output.
#
# Sample command line:
#   python encode_to_MOV_H264_1080p_with_audio.py inFile=path/name_####.jpg outFile=path/movie_name.mov frameList=0-100

from __future__ import absolute_import, print_function
import Draft
import os
import sys
from DraftParamParser import FrameRangeToFrames, ParseCommandLine, ReplaceFilenameHashesWithNumber

expectedTypes = dict()
expectedTypes['frameList'] = '<string>'
expectedTypes['inFile'] = '<string>'
expectedTypes['outFile'] = '<string>'

# Parse the command line arguments
params = ParseCommandLine(expectedTypes, sys.argv)

outWidth = 1920
outHeight = 1080
audio = None
path = params['inFile']
frames = FrameRangeToFrames(params['frameList'])

parent = os.path.dirname(os.path.dirname(path))

for file in os.listdir(parent):
    if file.lower().endswith('.wav') or file.lower().endswith('.aiff') or file.lower().endswith('.aif'):
        audio = file
        break

if audio is not None:
    encoder = Draft.VideoEncoder(params['outFile'], 23.976, outWidth, outHeight, codec="H264",
                                 audioFilename=os.path.join(parent, audio))
else:
    encoder = Draft.VideoEncoder(params['outFile'], 23.976, outWidth, outHeight, codec="H264")

progressCounter = 0
for frameNumber in frames:
    inFile = ReplaceFilenameHashesWithNumber(path, frameNumber)
    myFrame = Draft.Image.ReadFromFile(inFile)

    myFrame.Resize(outWidth, outHeight)

    encoder.EncodeNextFrame(myFrame)

    progressCounter = progressCounter + 1
    progress = progressCounter * 100 // len(frames)
    print("Progress: %i%%" % progress)

encoder.FinalizeEncoding()
